﻿using DiscUtils.Udf;
using Microsoft.Toolkit.Uwp.Notifications;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WindowsUpgradeService
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            //InitializeComponent();
            ExtractISO();
            SetupWindows();
        }
        static string OutPutWork = $"{Environment.GetEnvironmentVariable("SystemDrive")}\\WindowsSetup";
        private void ExtractISO()
        {
            using (Stream isoStream = File.Open($"{Directory.GetCurrentDirectory()}\\Windows_24H2.iso", FileMode.Open))
            {
                UdfReader udfReader = new UdfReader(isoStream);
                var DIRcd = udfReader.GetDirectories("\\", "*", SearchOption.AllDirectories);
                var FILEScd = udfReader.GetFiles("\\", "*", SearchOption.AllDirectories);

                if (Directory.Exists(OutPutWork))
                {
                    Directory.Delete(OutPutWork,true);
                }

                Directory.CreateDirectory(OutPutWork);

                foreach (var dir in DIRcd) {
                    Directory.CreateDirectory($"{OutPutWork}{dir}");
                }

                foreach (var files in FILEScd) {
                    Stream destOutput = File.OpenWrite($"{OutPutWork}{files}");
                    Stream fileStream = udfReader.OpenFile(files,FileMode.Open);
                    fileStream.CopyTo(destOutput);
                }
            }
        }

        private void SetupWindows()
        {
            var ProcStartInfo = new ProcessStartInfo()
            {
                FileName = $"{OutPutWork}\\setup.exe",
                Arguments = "/auto upgrade /quiet /noreboot",
                UseShellExecute = true,
                CreateNoWindow = true,

            };
            var ProcStart = new Process()
            {
                StartInfo = ProcStartInfo,
            };
            NotifyMe("The Upgrade is in Progress.", "Please do not shutdown or unplug your PC.");
            Window1 window1 = new Window1();
            window1.StatusLabel.Content = "The Upgrade is in Progress.";
            window1.Show();
            ProcStart.Start();
            ProcStart.WaitForExit();
            if (ProcStart.ExitCode != 0) {
                NotifyMe("The Upgrade Failed.", "Please try to install again later.");
                window1.StatusLabel.Content = "The Upgrade Failed.";
            }
            else {
                NotifyMe("Welcome to Windows 11.", "Please restart your machine and allow the setup to complete.");
                window1.StatusLabel.Content = "Please restart your machine and allow the setup to complete.";
            }

        }
        public void NotifyMe(string Title, string Message)
        {
            new ToastContentBuilder()
                .AddArgument("action", "viewConversation")
                .AddArgument("conversationId", 6969)
                .AddText(Title)
                .AddText(Message)
                .Show();
        }
        private void StatusLabel_Loaded(object sender, RoutedEventArgs e)
        {

        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
         Visibility = Visibility.Collapsed;
        }
    }
}
